@@ -8,13 +8,11 @@
 #ifndef _CONFIG_H
 #define _CONFIG_H
 
-/* Undefine this if you want to use the old Licq icons and not the
-   new dockable ones. */
-#define USE_DOCK
+/* Undefine this if the fifo causes problems */
+#define USE_FIFO
 
-/* Change this to MotifStyle if you want the old-school Motif
-   widget look. */
-#define STYLE WindowsStyle
+/* Undefine this if the compile complains about scandir_r and alphasort */
+#define ALPHASORT_VOID
 
 /* The name of the package we're compiling */
 #undef PACKAGE
@@ -28,18 +26,14 @@
 /* Whether or not to include SOCKS5 firewall support */
 #undef USE_SOCKS5
 
-/* Whether or not to include KDE support */
-#undef USE_KDE
-
 /* Define this if the system headers don't */
 #undef socklen_t
 
 /* Do we have sys_errlist[] available? */
 #undef HAVE_SYS_ERRLIST
 
-/* This gets defined if the system has the MIT X11 screensaver extensions */
-#undef USE_SCRNSAVER
-
+/* Policy used for dlopen() mode */
+#undef DLOPEN_POLICY
 @TOP@
 @BOTTOM@
 
